@@ -62,9 +62,19 @@ class c获取属性:
         return f'{self.变量}.{self.属性}'
 
 
+class c函数调用:
+    def __init__(self, 函数名, 参数字符串) -> None:
+        self.函数名 = 函数名
+        self.参数字符串 = 参数字符串
+
+    def __str__(self) -> str:
+        return f'{self.函数名}({self.参数字符串})'
+
+
 class py2cpp编译器(ast.NodeVisitor):
-    def __init__(self, 被编译的函数: Callable) -> None:
+    def __init__(self, 被编译的函数: Callable, c编译器) -> None:
         self.被编译的函数 = 被编译的函数
+        self.c编译器: cpp编译器 = c编译器
         self.源代码 = inspect.getsource(被编译的函数)
         self.代码哈希值 = hashlib.blake2s(
             self.源代码.encode(), digest_size=8).hexdigest()
@@ -77,7 +87,7 @@ class py2cpp编译器(ast.NodeVisitor):
         self.参数不同c类型前置处理函数 = {}
         self.ascendc变量对应表: List[Dict[str, Any]] = [{}]
         self.当前上下文层级 = 0
-        self.依赖函数 = []
+        self.依赖函数: List[py2cpp编译器] = []
         self.函数映射表 = {}
         self.代码序列 = []
         self.花括号 = 花括号(self)
@@ -98,6 +108,18 @@ class py2cpp编译器(ast.NodeVisitor):
     def 编译(self):
         语法树 = ast.parse(self.源代码)
         self.visit(语法树)
+        # 读取依赖函数
+        cpps = [f'{通用信息.工作文件夹地址}/{self.获取cpp文件名()}']
+        for b in self.依赖函数:
+            self.include目录.add(f'"{b.获取h文件名()}"')
+            cpps.append(f'{通用信息.工作文件夹地址}/{b.获取cpp文件名()}')
+
+        self.将代码保存到文件()
+        self.c编译器.include目录列表 = list(self.include目录)
+        self.c编译器.库目录列表 = list(self.库目录)
+        self.c编译器.链接库 = list(self.链接库列表)
+        输出路径 = f'{通用信息.工作文件夹地址}/{self.获取库文件名()}'
+        self.c编译器.编译为动态库(cpps, 输出路径=输出路径)
 
     def 添加c代码(self, 代码: str):
         self.代码序列.append(c代码(代码, self.当前上下文层级))
@@ -288,19 +310,20 @@ class py2cpp编译器(ast.NodeVisitor):
         if not isinstance(fn, Callable):
             self.抛出代码异常(f'{ast.dump(node.func)} 没找到', node)
 
-        依赖函数编译器 = self.__class__(fn)
-        依赖函数编译器.编译()
-
-        # 添加依赖
-        self.依赖函数.append(依赖函数编译器)
-
-        # 构建调用代码
         if len(node.keywords) > 0:
             self.代码异常抛出器('暂不支持 keywords 函数调用', node)
 
         参数列表 = [str(self.获取值(arg)) for arg in node.args]
         参数字符串 = ','.join(参数列表)
-        return f'{fn.__name__}({参数字符串});'
+
+        if isinstance(fn, py2cpp编译器):
+            self.依赖函数.append(fn)
+            return c函数调用(fn.c函数名, 参数字符串)
+        else:
+            依赖函数编译器 = self.__class__(fn, self.c编译器)
+            依赖函数编译器.编译()
+            self.依赖函数.append(依赖函数编译器)
+            return c函数调用(fn.__name__, 参数字符串)
 
     def 获取Subscript(self, node: ast.Subscript):
         对象 = self.获取值(node.value)
@@ -454,7 +477,7 @@ class py2cpp编译器(ast.NodeVisitor):
 
     def visit_Call(self, node: ast.Call) -> Any:
         代码 = self.调用Call(node)
-        self.添加c代码(代码)
+        self.添加c代码(str(代码))
 
     def _赋值(self, target, 值, node):
         目标 = self.获取值(target)
@@ -545,7 +568,8 @@ class py2cpp编译器(ast.NodeVisitor):
             fp.write(cpp代码)
 
     def 加载库(self):
-        self.目标库 = ctypes.CDLL(f'{通用信息.工作文件夹地址}/{self.获取库文件名()}')
+        库地址 = f'{通用信息.工作文件夹地址}/{self.获取库文件名()}'
+        self.目标库 = ctypes.CDLL(库地址)
         self.cpp函数 = self.目标库[self.c函数名]
         self.cpp函数.argtypes = self.ctypes类型
         self.cpp函数.restype = self.ctypes返回类型
@@ -554,25 +578,15 @@ class py2cpp编译器(ast.NodeVisitor):
         return self.cpp函数(*args)
 
 
-def jit(jit编译器=None, c编译器=None, 每次运行都重新编译: bool = False):
+def jit(jit编译器类=None, cpp编译器类=None, 每次运行都重新编译: bool = False):
     def 编译函数(fn: Callable):
-
         # print(ast.dump(语法树, indent=' '))
-        c语言函数编译器 = jit编译器 or py2cpp编译器(fn)
+        _c编译器类 = cpp编译器类 or cpp编译器
+        _jit编译器类 = jit编译器类 or py2cpp编译器
+        c语言函数编译器 = _jit编译器类(fn, _c编译器类())
         库文件名 = c语言函数编译器.获取库文件名()
-        # 检测是否已存在
         if 每次运行都重新编译 or not os.path.exists(f'{通用信息.工作文件夹地址}/{库文件名}'):
             c语言函数编译器.编译()
-            c语言函数编译器.将代码保存到文件()
-            编译器 = c编译器 or cpp编译器()
-            编译器.include目录列表 = list(c语言函数编译器.include目录)
-            编译器.库目录列表 = list(c语言函数编译器.库目录)
-            编译器.链接库 = list(c语言函数编译器.链接库列表)
-            编译器.编译为动态库(f'{通用信息.工作文件夹地址}/{c语言函数编译器.获取cpp文件名()}',
-                       f'{通用信息.工作文件夹地址}/{c语言函数编译器.获取库文件名()}')
         c语言函数编译器.加载库()
-
-        def call(*args):
-            return c语言函数编译器(*args)
-        return call
+        return c语言函数编译器
     return 编译函数
